@@ -48,7 +48,7 @@ def get_readline_file_object(expr: Expression) -> NameExpr | None:
                 expr=NameExpr(node=Var(type=ty)) as f, name="readlines"
             ),
             args=[],
-        ) if str(ty) == "io.TextIOWrapper":
+        ) if str(ty) in ("io.TextIOWrapper", "io.BufferedReader"):
             return f
 
     return None
