@@ -1,6 +1,7 @@
 from dataclasses import dataclass
 
 from mypy.nodes import (
+    ArgKind,
     Argument,
     Block,
     CallExpr,
@@ -44,22 +45,17 @@ def get_lambda_arg_names(args: list[Argument]) -> list[str]:
     return [arg.variable.name for arg in args]
 
 
-def get_func_names(args: list[Expression]) -> list[str] | None:
-    names = []
-
-    for arg in args:
-        if not isinstance(arg, NameExpr):
-            return None
-
-        names.append(arg.name)
-
-    return names
+def get_func_arg_names(args: list[Expression]) -> list[str | None]:
+    return [arg.name if isinstance(arg, NameExpr) else None for arg in args]
 
 
 def check(node: LambdaExpr, errors: list[Error]) -> None:
     match node:
         case LambdaExpr(
             arguments=lambda_args,
-            body=Block(body=[ReturnStmt(expr=CallExpr(args=func_args))]),
-        ) if get_lambda_arg_names(lambda_args) == get_func_names(func_args):
+            body=Block(body=[ReturnStmt(expr=CallExpr() as func)]),
+        ) if (
+            get_lambda_arg_names(lambda_args) == get_func_arg_names(func.args)
+            and all(kind == ArgKind.ARG_POS for kind in func.arg_kinds)
+        ):
             errors.append(ErrorInfo(node.line, node.column))
