@@ -7,30 +7,48 @@ from importlib.metadata import entry_points
 from inspect import signature
 from pathlib import Path
 from types import ModuleType, UnionType
-from typing import Callable, Type, cast
+from typing import cast
 
 from mypy.nodes import Node
 
 from . import checks as checks_module
 from .error import Error, ErrorCode
 from .settings import Settings
-
-Check = Callable[[Node, list[Error]], None]
+from .types import Check
 
 
 def get_modules(paths: list[str]) -> Generator[ModuleType, None, None]:
     sys.path.append(str(Path.cwd()))
 
     plugins = [x.value for x in entry_points(group="refurb.plugins")]
+    extra_modules = (importlib.import_module(x) for x in paths + plugins)
 
-    extra_modules = (__import__(x) for x in paths + plugins)
+    loaded: set[ModuleType] = set()
 
     for pkg in (checks_module, *extra_modules):
+        if pkg in loaded:
+            continue
+
+        if not hasattr(pkg, "__path__"):
+            module = importlib.import_module(pkg.__name__)
+
+            if module not in loaded:
+                loaded.add(module)
+                yield module
+
+            continue
+
         for info in pkgutil.walk_packages(pkg.__path__, f"{pkg.__name__}."):
             if info.ispkg:
                 continue
 
-            yield importlib.import_module(info.name)
+            module = importlib.import_module(info.name)
+
+            if module not in loaded:
+                loaded.add(module)
+                yield module
+
+        loaded.add(pkg)
 
 
 def get_error_class(module: ModuleType) -> type[Error] | None:
@@ -41,22 +59,24 @@ def get_error_class(module: ModuleType) -> type[Error] | None:
     return None
 
 
-def load_checks(settings: Settings) -> defaultdict[Type[Node], list[Check]]:
-    found: defaultdict[Type[Node], list[Check]] = defaultdict(list)
-    ignore = settings.ignore or set()
-    paths = settings.load or []
-    enabled = settings.enable or set()
+def should_skip_loading_check(settings: Settings, error: type[Error]) -> bool:
+    error_code = ErrorCode.from_error(error)
 
-    for module in get_modules(paths):
+    error_is_disabled = settings.disable_all or not error.enabled
+    should_enable = settings.enable_all or error_code in settings.enable
+
+    in_disable_list = error_code in (settings.ignore | settings.disable)
+
+    return (error_is_disabled and not should_enable) or in_disable_list
+
+
+def load_checks(settings: Settings) -> defaultdict[type[Node], list[Check]]:
+    found: defaultdict[type[Node], list[Check]] = defaultdict(list)
+
+    for module in get_modules(settings.load):
         error = get_error_class(module)
-        if not error:
-            continue
 
-        error_code = ErrorCode.from_error(error)
-
-        is_enabled = error.enabled or error_code in enabled
-
-        if not is_enabled or error_code in ignore:
+        if not error or should_skip_loading_check(settings, error):
             continue
 
         if func := getattr(module, "check", None):
