@@ -20,7 +20,9 @@ from .visitor import RefurbVisitor
 def usage() -> None:
     print(
         """\
-usage: refurb [--ignore err] [--load path] [--debug] [--quiet] [--enable] src [srcs...]
+usage: refurb [--ignore err] [--load path] [--debug] [--quiet] [--enable err]
+              [--disable err] [--disable-all] [--enable-all]
+              [--config-file path] [--python-version version] src [srcs...]
        refurb [--help | -h]
        refurb [--version | -v]
        refurb --explain err
@@ -28,16 +30,20 @@ usage: refurb [--ignore err] [--load path] [--debug] [--quiet] [--enable] src [s
 
 Command Line Options:
 
--h, --help       This help menu.
---version, -v    Print version information.
---ignore err     Ignore an error. Can be repeated.
---load module    Add a module to the list of paths to be searched when looking
-                 for checks. Can be repeated.
---debug          Print the AST representation of all files that where checked.
---quiet          Suppress default "--explain" suggestion when an error occurs.
---enable         Load a check which is disabled.
---explain        Print the explaination/documentation from a given error code.
-src              A file or folder.
+--help, -h            This help menu.
+--version, -v         Print version information.
+--ignore err          Ignore an error. Can be repeated.
+--load module         Add a module to the list of paths to be searched when looking for checks. Can be repeated.
+--debug               Print the AST representation of all files that where checked.
+--quiet               Suppress default "--explain" suggestion when an error occurs.
+--enable err          Load a check which is disabled by default.
+--disable err         Disable loading a check which is enabled by default.
+--config-file file    Load "file" instead of the default config file.
+--explain err         Print the explaination/documentation from a given error code.
+--disable-all         Disable all checks by default.
+--enable-all          Enable all checks by default.
+--python-version x.y  Version of the Python code being checked.
+src                   A file or folder.
 
 
 Subcommands:
@@ -91,6 +97,11 @@ def run_refurb(settings: Settings) -> Sequence[Error | str]:
     opt.incremental = True
     opt.fine_grained_incremental = True
     opt.cache_fine_grained = True
+    opt.allow_redefinition = True
+    opt.local_partial_types = True
+
+    if settings.python_version:
+        opt.python_version = settings.python_version  # pragma: no cover
 
     try:
         result = build(files, options=opt)
@@ -106,7 +117,7 @@ def run_refurb(settings: Settings) -> Sequence[Error | str]:
                 errors.append(str(tree))
 
             checks = load_checks(settings)
-            visitor = RefurbVisitor(checks)
+            visitor = RefurbVisitor(checks, settings)
 
             tree.accept(visitor)
 
